## Sid Meier's Civilization 4
## Copyright Firaxis Games 2005

from CvPythonExtensions import *
import sdToolKit
import CvUtil
import CvEventManager
import PyHelpers
import CvAdvisorUtils
import sys
import CustomFunctions
	
# globals
gc = CyGlobalContext()
PyPlayer = PyHelpers.PyPlayer
cf = CustomFunctions.CustomFunctions()
sd = sdToolKit
###################################################
class CvCustomEventManager(CvEventManager.CvEventManager):
	
	def onTechAcquired(self, argsList):
		'Tech Acquired'
		iTechType, iTeam, iPlayer, bAnnounce = argsList
		# Note that iPlayer may be NULL (-1) and not a refer to a player object
		
		# Show tech splash when applicable
		if (iPlayer > -1 and bAnnounce and not CyInterface().noTechSplash()):
			if (gc.getGame().isFinalInitialized() and not gc.getGame().GetWorldBuilder2Mode()):
				if ((not CyGame().isNetworkMultiPlayer()) and (iPlayer == CyGame().getActivePlayer())):
					popupInfo = CyPopupInfo()
					popupInfo.setButtonPopupType(ButtonPopupTypes.BUTTONPOPUP_PYTHON_SCREEN)
					popupInfo.setData1(iTechType)
					popupInfo.setText(u"showTechSplash")
					popupInfo.addPopup(iPlayer)

		cf.UpgradeOnTech(iPlayer, iTechType)

	def onUnitCreated(self, argsList):
		#sd.sdEcho("A unit has been created")
		'Unit Completed'
		unit = argsList[0]
		player = PyPlayer(unit.getOwner())
		cf.UpgradeOnCreated(unit, player)

	def onBeginPlayerTurn(self, argsList):
		'Called at the beginning of a players turn'
		iGameTurn, iPlayer = argsList
		list = [["BRONZE_WORKING", "ARCHER", "CHARIOT"], ["PRIESTHOOD", "CHARIOT"],  ["IRON_WORKING", "SPEARMAN", "AXEMAN"], ["METAL_CASTING", "SPEARMAN", "AXEMAN", "SWORDSMAN"], ["CONSTRUCTION", "CATAPULT","ARCHER"], ["MATHEMATICS", "ARCHER"], ["MONARCHY", "HORSE_ARCHER"], ["CURRENCY", "HORSE_ARCHER"], ["MACHINERY", "CATAPULT", "WAR_ELEPHANT"], ["GUILDS", "TREBUCHET", "MACEMAN"], ["OPTICS", "LONGBOWMAN"], ["ENGINEERING", "CROSSBOWMAN", "WAR_ELEPHANT"], ["MUSIC", "KNIGHT"], ["EDUCATION", "TREBUCHET", "KNIGHT"], ["PRINTING_PRESS", "LONGBOWMAN", "CROSSBOWMAN"], ["NATIONALISM", "MACEMAN", "PIKEMAN"], ["CONSTITUTION", "PIKEMAN"], ["LIBERALISM", "MUSKETMAN"], ["REPLACEABLE_PARTS", "GRENADIER"], ["RIFLING", "CAVALRY"], ["STEEL", "CANNON", "GRENADIER"], ["RAILROAD", "CAVALRY"], ["SCIENTIFIC_METHOD", "RIFLEMAN"], ["FASCISM", "CAVALRY"], ["PHYSICS", "RIFLEMAN"],["ASSEMBLY_LINE", "MACHINE_GUNNER"], ["INDUSTRIALISM", "INFANTRY"], ["RADIO", "ARTILERY", "TANK"], ["ROCKETRY", "INFANTRY"], ["MASS_MEDIA", "MARINE"], ["COMPOSITES", "ARTILERY"], ["COMPUTERS", "MARINE"], ["ROBOTICS", "SAM_INFANTRY"], ["FIBER_OPTICS", "GUNSHIP"]]
		if iPlayer == 0:
			iRealPlayer = gc.getGame().countCivPlayersEverAlive() - 1
		elif iPlayer == 18:
			iRealPlayer = 19
		else:
			iRealPlayer = iPlayer - 1
		#sd.sdEcho("This is %s 's turn" %iPlayer)
		#sd.sdEcho("and it is affecting %s 's unit" %iRealPlayer)
		iNumUnits = gc.getPlayer(iRealPlayer).getNumUnits()
		#sd.sdEcho("the player has %i units" % iNumUnits)
		pPlayer = gc.getPlayer(iRealPlayer)
		pTeam = gc.getTeam(pPlayer.getTeam())
		for Tech in list:
			if pTeam.isHasTech(gc.getInfoTypeForString("TECH_"+Tech[0])):
				#sd.sdEcho(Tech)
				for UnitClass in Tech[1:]:
					for iUnit in range(0, (iNumUnits + 1)):
						pUnit = gc.getPlayer(iRealPlayer).getUnit(iUnit)
						#sd.sdEcho("looking at unit %s" % pUnit.getName()) 
						if pUnit.getUnitClassType() != gc.getInfoTypeForString("UNITCLASS_"+UnitClass):
							if pUnit.isHasPromotion(gc.getInfoTypeForString("PROMOTION_"+Tech[0]+"_"+UnitClass)):
								#sd.sdEcho("Unit %i has just been DEmoted" % iUnit)
								pUnit.setHasPromotion(gc.getInfoTypeForString("PROMOTION_"+Tech[0]+"_"+UnitClass), False)
		#sd.sdEcho("")